#[non_exhaustive]pub struct UpdateFilePolicyArg {
pub file: PathOrId,
pub actions: Option<Vec<FileAction>>,
pub link_settings: Option<LinkSettings>,
pub viewer_info_policy: Option<ViewerInfoPolicy>,
}Available on crate features
async_routes and dbx_sharing only.Expand description
Arguments for update_file_policy().
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file: PathOrIdFile that we are changing the policy for.
actions: Option<Vec<FileAction>>A list of FileActions corresponding to FilePermissions that should appear in the
response’s SharedFileMetadata::permissions field describing the
actions the authenticated user can perform on the file.
link_settings: Option<LinkSettings>👎Deprecated
Field is deprecated. Settings on the link for the file.
viewer_info_policy: Option<ViewerInfoPolicy>The presence and seen state policy on the file.
Implementations
Sourceimpl UpdateFilePolicyArg
impl UpdateFilePolicyArg
pub fn new(file: PathOrId) -> Self
pub fn with_actions(self, value: Vec<FileAction>) -> Self
pub fn with_link_settings(self, value: LinkSettings) -> Self
👎Deprecated
pub fn with_viewer_info_policy(self, value: ViewerInfoPolicy) -> Self