#[non_exhaustive]pub enum NoPermissionError {
UnauthorizedAccountIdUsage(UnauthorizedAccountIdUsageError),
Other,
}Available on crate feature
sync_routes only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Current caller does not have permission to access the account information for one or more of the specified account IDs.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.