[−][src]Enum dropbox_sdk::files::RelocationBatchErrorEntry
Variants
RelocationError(RelocationError)User errors that retry won't help.
InternalErrorSomething went wrong with the job on Dropbox's end. You'll need to verify that the action you were taking succeeded, and if not, try again. This should happen very rarely.
TooManyWriteOperationsThere are too many write operations in user's Dropbox. Please retry this request.
OtherCatch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.