#[non_exhaustive]pub enum UploadSessionAppendBatchEntryError {
NotFound,
IncorrectOffset(UploadSessionOffsetError),
Closed,
TooLarge,
ConcurrentSessionInvalidOffset,
ConcurrentSessionInvalidDataSize,
Other,
}sync_routes and dbx_files only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
NotFound
The upload session ID was not found or has expired. Upload sessions are valid for 7 days.
IncorrectOffset(UploadSessionOffsetError)
The specified offset was incorrect. See the value for the correct offset. This error may occur when a previous request was received and processed successfully but the client did not receive the response, e.g. due to a network error.
Closed
You are attempting to append data to an upload session that has already been closed (i.e. committed).
TooLarge
You can not append to the upload session because the size of a file should not exceed the max file size limit (i.e. 2^41 - 2^22 or 2,199,019,061,248 bytes).
ConcurrentSessionInvalidOffset
For concurrent upload sessions, offset needs to be multiple of 2^22 (4,194,304) bytes.
ConcurrentSessionInvalidDataSize
For concurrent upload sessions, only chunks with size multiple of 2^22 (4,194,304) bytes can be uploaded.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.