#[non_exhaustive]pub enum UploadSessionAppendBatchError {
PayloadTooLarge,
ContentHashMismatch,
LengthMismatch,
Other,
}Available on crate features
dbx_files and sync_routes only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PayloadTooLarge
The request payload must be at most 150 MiB.
ContentHashMismatch
The content received by the Dropbox server in this call does not match the provided content hash.
LengthMismatch
The total length of the content received by the Dropbox server in this call does not match the total of the provided lengths in the batch arguments.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.