#[non_exhaustive]pub struct ListRevisionsResult {
pub is_deleted: bool,
pub entries: Vec<FileMetadata>,
pub has_more: bool,
pub server_deleted: Option<DropboxTimestamp>,
}Available on crate features
dbx_files and sync_routes only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_deleted: boolIf the file identified by the latest revision in the response is either deleted or moved. If before_rev is set, this refers to the latest revision of the file older than before_rev.
entries: Vec<FileMetadata>The revisions for the file. Only revisions that are not deleted will show up here.
has_more: boolIf true, then there are more entries available. Call list_revisions again with before_rev equal to the revision of the last returned entry to retrieve the rest.
server_deleted: Option<DropboxTimestamp>The time of deletion if the file was deleted.
Implementations
Sourceimpl ListRevisionsResult
impl ListRevisionsResult
pub fn new(is_deleted: bool, entries: Vec<FileMetadata>, has_more: bool) -> Self
pub fn with_server_deleted(self, value: DropboxTimestamp) -> Self