docs_folder_users_list

Function docs_folder_users_list 

pub fn docs_folder_users_list(
    client: &impl UserAuthClient,
    arg: &ListUsersOnFolderArgs,
) -> Result<ListUsersOnFolderResponse, Error<DocLookupError>>
👎Deprecated
Available on crate features dbx_paper and sync_routes only.
Lists the users who are explicitly invited to the Paper folder in which the Paper doc is contained. For private folders all users (including owner) shared on the folder are listed and for team folders all non-team users shared on the folder are returned. Note that this endpoint will continue to work for content created by users on the older version of Paper. To check which version of Paper a user is on, use /users/features/get_values. If the paper_as_files feature is enabled, then the user is running the new version of Paper. Refer to the Paper Migration Guide for migration information.