docs_folder_users_list_continue

Function docs_folder_users_list_continue 

pub fn docs_folder_users_list_continue(
    client: &impl UserAuthClient,
    arg: &ListUsersOnFolderContinueArgs,
) -> Result<ListUsersOnFolderResponse, Error<ListUsersCursorError>>
👎Deprecated
Available on crate features sync_routes and dbx_paper only.
Once a cursor has been retrieved from docs_folder_users_list(), use this to paginate through all users on the Paper folder. Note that this endpoint will continue to work for content created by users on the older version of Paper. To check which version of Paper a user is on, use /users/features/get_values. If the paper_as_files feature is enabled, then the user is running the new version of Paper. Refer to the Paper Migration Guide for migration information.