pub fn docs_list_continue(
client: &impl UserAuthClient,
arg: &ListPaperDocsContinueArgs,
) -> Result<ListPaperDocsResponse, Error<ListDocsCursorError>>👎Deprecated
Available on crate features
dbx_paper and sync_routes only.Expand description
Once a cursor has been retrieved from docs_list(), use this to
paginate through all Paper doc. Note that this endpoint will continue to work for content
created by users on the older version of Paper. To check which version of Paper a user is on,
use /users/features/get_values. If the paper_as_files feature is enabled, then the user is
running the new version of Paper. Refer to the Paper Migration
Guide for migration
information.