pub fn docs_users_list_continue(
client: &impl UserAuthClient,
arg: &ListUsersOnPaperDocContinueArgs,
) -> Result<ListUsersOnPaperDocResponse, Error<ListUsersCursorError>>👎Deprecated
Available on crate features
dbx_paper and sync_routes only.Expand description
Once a cursor has been retrieved from docs_users_list(), use
this to paginate through all users on the Paper doc. Note that this endpoint will continue to
work for content created by users on the older version of Paper. To check which version of Paper
a user is on, use /users/features/get_values. If the paper_as_files feature is enabled, then the
user is running the new version of Paper. Refer to the Paper Migration
Guide for migration
information.