FileIdOrUrl

Enum FileIdOrUrl 

#[non_exhaustive]
pub enum FileIdOrUrl { FileId(String), Url(String), Path(String), Other, }
Available on crate features dbx_riviera and sync_routes only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


FileId(String)

A Dropbox-issued file id (format: “id:”) for a file the authenticated user has access to.



Url(String)

Either a Dropbox shared link (www.dropbox.com) or an external HTTP or HTTPS URL pointing to a supported file. - Dropbox shared links are resolved internally using the caller’s authenticated identity and the link’s visibility / download settings. They therefore require an authenticated user context (anonymous url requests against Dropbox links are rejected with an access_error). Links protected by a password are rejected with shared_link_password_protected; links with downloads disabled are rejected with link_download_disabled_error. - External URLs are fetched through the backend’s egress proxy and must point at a supported file extension.



Path(String)

An absolute Dropbox path, e.g. “/folder/example.pdf”.



Other

Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.