#[non_exhaustive]pub enum MetadataExtractionApiV2Error {
ServerError(String),
UserError(String),
UnsupportedFormatError,
LinkDownloadDisabledError,
SharedLinkPasswordProtected,
LimitExceededError,
ConversionFailureError,
NotFoundError,
IsAFolderError,
Other,
}Available on crate features
dbx_riviera and sync_routes only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ServerError(String)
UserError(String)
UnsupportedFormatError
LinkDownloadDisabledError
LimitExceededError
ConversionFailureError
NotFoundError
The referenced file does not exist or is not accessible.
IsAFolderError
The target is a folder, not a file.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.