CreateSharedLinkWithSettingsError

Enum CreateSharedLinkWithSettingsError 

pub enum CreateSharedLinkWithSettingsError {
    Path(LookupError),
    EmailNotVerified,
    SharedLinkAlreadyExists(Option<SharedLinkAlreadyExistsMetadata>),
    SettingsError(SharedLinkSettingsError),
    AccessDenied,
    BannedMember,
    TooManySharedFolders,
}
Available on crate features dbx_sharing and sync_routes only.

Variants



Path(LookupError)



EmailNotVerified

This user’s email address is not verified. This functionality is only available on accounts with a verified email address. Users can verify their email address here.



SharedLinkAlreadyExists(Option<SharedLinkAlreadyExistsMetadata>)

The shared link already exists. You can call list_shared_links() to get the existing link, or use the provided metadata if it is returned. Existing link metadata will not be returned if custom settings were specified in the request that could make the existing link incompatible with the requested settings.



SettingsError(SharedLinkSettingsError)

There is an error with the given settings.



AccessDenied

The user is not allowed to create a shared link to the specified file. For example, this can occur if the file is restricted or if the user’s links are banned.



BannedMember

The current user has been banned for abuse reasons.



TooManySharedFolders

Your Dropbox folder will have too many shared folders after the operation. https://help.dropbox.com/share/shared-folder-faq#Is-there-a-limit-to-the-number-of-shared-folders-I-can-create