#[non_exhaustive]pub enum FileAction {
Show 13 variants
DisableViewerInfo,
EditContents,
EnableViewerInfo,
InviteViewer,
InviteViewerNoComment,
InviteEditor,
Unshare,
RelinquishMembership,
ShareLink,
CreateLink,
CreateViewLink,
CreateEditLink,
Other,
}dbx_sharing and sync_routes only.Expand description
Sharing actions that may be taken on files.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DisableViewerInfo
Disable viewer information on the file.
EditContents
Change or edit contents of the file.
EnableViewerInfo
Enable viewer information on the file.
InviteViewer
Add a member with view permissions.
InviteViewerNoComment
Add a member with view permissions but no comment permissions.
InviteEditor
Add a member with edit permissions.
Stop sharing this file.
RelinquishMembership
Relinquish one’s own membership to the file.
Field is deprecated. Use create_view_link and create_edit_link instead.
CreateLink
Field is deprecated. Use create_view_link and create_edit_link instead.
CreateViewLink
Create a shared link to a file that only allows users to view the content.
CreateEditLink
Create a shared link to a file that allows users to edit the content.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.