#[non_exhaustive]pub enum RelinquishAccessError {
InvalidFileId,
EmailUnverified,
Owner,
NoExplicitAccess,
TeamFolder,
NoPermission,
Other,
}dbx_sharing and sync_routes only.Expand description
Error result for the relinquish_access endpoint.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidFileId
File or folder not found or has been deleted.
EmailUnverified
Caller’s email address is not verified.
Owner
User is the owner of the file/folder.
NoExplicitAccess
User has only non-removable access — inherited from a parent folder or via group membership. Either way, relinquish_access cannot remove the caller’s access from this surface; the caller must take action on the source of the access (e.g. leave the parent shared folder, or be removed from the group).
TeamFolder
Team folder restrictions apply.
NoPermission
Caller does not have permission to perform this action. Generic fallback.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.