#[non_exhaustive]pub enum RelinquishFileMembershipError {
AccessError(SharingFileAccessError),
GroupAccess,
NoPermission,
Other,
}Available on crate features
dbx_sharing and sync_routes only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AccessError(SharingFileAccessError)
GroupAccess
The current user has access to the shared file via a group. You can’t relinquish membership to a file shared via groups.
NoPermission
The current user does not have permission to perform this action.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.