SharePathErrorBaseV2

Enum SharePathErrorBaseV2 

#[non_exhaustive]
pub enum SharePathErrorBaseV2 {
Show 15 variants IsFile, InsideSharedFolder, ContainsSharedFolder, ContainsTeamFolder, IsAppFolder, InsideAppFolder, IsPublicFolder, InsidePublicFolder, AlreadyShared(SharedFolderMetadata), InvalidPath, IsOsxPackage, InsideOsxPackage, IsVault, IsVaultLocked, Other,
}
Available on crate features dbx_sharing and sync_routes only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


IsFile

A file is at the specified path.



InsideSharedFolder

We do not support sharing a folder inside a shared folder.



ContainsSharedFolder

We do not support shared folders that contain shared folders.



ContainsTeamFolder

We do not support shared folders that contain team folders.



IsAppFolder

We do not support sharing an app folder.



InsideAppFolder

We do not support sharing a folder inside an app folder.



IsPublicFolder

A public folder can’t be shared this way. Use a public link instead.



InsidePublicFolder

A folder inside a public folder can’t be shared this way. Use a public link instead.



AlreadyShared(SharedFolderMetadata)

Folder is already shared. Contains metadata about the existing shared folder.



InvalidPath

Path is not valid.



IsOsxPackage

We do not support sharing a Mac OS X package.



InsideOsxPackage

We do not support sharing a folder inside a Mac OS X package.



IsVault

We do not support sharing the Vault folder.



IsVaultLocked

We do not support sharing a folder inside a locked Vault.



Other

Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.