mount_folder

Function mount_folder 

pub fn mount_folder(
    client: &impl UserAuthClient,
    arg: &MountFolderArg,
) -> Result<SharedFolderMetadata, Error<MountFolderError>>
Available on crate features dbx_sharing and sync_routes only.
The current user mounts the designated folder. Mount a shared folder for a user after they have been added as a member. Once mounted, the shared folder will appear in their Dropbox.