share_folder

Function share_folder 

pub fn share_folder(
    client: &impl UserAuthClient,
    arg: &ShareFolderArg,
) -> Result<ShareFolderLaunch, Error<ShareFolderError>>
Available on crate features dbx_sharing and sync_routes only.
Share a folder with collaborators. Most sharing will be completed synchronously. Large folders will be completed asynchronously. To make testing the async case repeatable, set ShareFolderArg.force_async. If a ShareFolderLaunch::AsyncJobId is returned, you’ll need to call check_share_job_status() until the action completes to get the metadata for the folder.