pub fn transfer_folder(
client: &impl UserAuthClient,
arg: &TransferFolderArg,
) -> Result<(), Error<TransferFolderError>>Available on crate features
dbx_sharing and sync_routes only.Expand description
Transfer ownership of a shared folder to a member of the shared folder. User must have
AccessLevel::Owner access to the shared folder to perform a transfer.