#[non_exhaustive]pub enum TeamFolderStatus {
Active,
Archived,
ArchiveInProgress,
Inactive,
Other,
}Available on crate features
sync_routes and dbx_team only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Active
The team folder and sub-folders are available to all members.
Archived
The team folder is archived and is not accessible outside of the team folder manager.
ArchiveInProgress
The team folder is in the process of being archived and is not accessible outside of the team folder manager.
Inactive
The team folder is unmounted and can be restored.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.