#[non_exhaustive]pub struct MembersFormerMemberArg {
pub user: UserSelectorArg,
}Available on crate features
sync_routes and dbx_team only.Expand description
Exactly one of team_member_id, email, or external_id must be provided to identify a former team member.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user: UserSelectorArgIdentity of user whose files will be permanently deleted.
Implementations
Sourceimpl MembersFormerMemberArg
impl MembersFormerMemberArg
pub fn new(user: UserSelectorArg) -> Self