#[non_exhaustive]pub struct SharingAllowlistAddArgs {
pub domains: Option<Vec<String>>,
pub emails: Option<Vec<String>>,
}Available on crate features
sync_routes and dbx_team only.Expand description
Structure representing Approve List entries. Domain and emails are supported. At least one entry of any supported type is required.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domains: Option<Vec<String>>List of domains represented by valid string representation (RFC-1034/5).
emails: Option<Vec<String>>List of emails represented by valid string representation (RFC-5322/822).
Implementations
Sourceimpl SharingAllowlistAddArgs
impl SharingAllowlistAddArgs
pub fn with_domains(self, value: Vec<String>) -> Self
pub fn with_emails(self, value: Vec<String>) -> Self