#[non_exhaustive]pub enum SignExternalSharingPolicy {
Default,
Disabled,
Enabled,
Other,
}Available on crate features
dbx_team_log and sync_routes only.Expand description
Policy for deciding whether team users can share Sign content externally
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Default
Disabled
Enabled
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.