#[non_exhaustive]pub struct DashDeletedCommentFromStackDetails {
pub stack_name: String,
pub stack_item_name: String,
pub stack_type: Option<DashStackType>,
}Available on crate features
sync_routes and dbx_team_log only.Expand description
Deleted a comment from a stack.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stack_name: StringThe name of the stack where the comment exists.
stack_item_name: StringThe name of the stack item that the comment is tied to.
stack_type: Option<DashStackType>The type of stack backend.
Implementations
Sourceimpl DashDeletedCommentFromStackDetails
impl DashDeletedCommentFromStackDetails
pub fn new(stack_name: String, stack_item_name: String) -> Self
pub fn with_stack_type(self, value: DashStackType) -> Self