#[non_exhaustive]pub struct MemberChangeStatusDetails {
pub new_value: MemberStatus,
pub previous_value: Option<MemberStatus>,
pub action: Option<ActionDetails>,
pub new_team: Option<String>,
pub previous_team: Option<String>,
}Available on crate features
dbx_team_log and sync_routes only.Expand description
Changed member status (invited, joined, suspended, etc.).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.new_value: MemberStatusNew member status.
previous_value: Option<MemberStatus>Previous member status. Might be missing due to historical data gap.
action: Option<ActionDetails>Additional information indicating the action taken that caused status change.
new_team: Option<String>The user’s new team name. This field is relevant when the user is transferred off the team.
previous_team: Option<String>The user’s previous team name. This field is relevant when the user is transferred onto the team.
Implementations
Sourceimpl MemberChangeStatusDetails
impl MemberChangeStatusDetails
pub fn new(new_value: MemberStatus) -> Self
pub fn with_previous_value(self, value: MemberStatus) -> Self
pub fn with_action(self, value: ActionDetails) -> Self
pub fn with_new_team(self, value: String) -> Self
pub fn with_previous_team(self, value: String) -> Self