#[non_exhaustive]pub struct MissingDetails {
pub source_event_fields: Option<String>,
}Available on crate features
dbx_team_log and sync_routes only.Expand description
An indication that an error occurred while retrieving the event. Some attributes of the event may be omitted as a result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_event_fields: Option<String>All the data that could be retrieved and converted from the source event.
Implementations
Sourceimpl MissingDetails
impl MissingDetails
pub fn with_source_event_fields(self, value: String) -> Self