#[non_exhaustive]pub enum FileProviderMigrationPolicyState {
Disabled,
Enabled,
Default,
Immediate,
Other,
}Available on crate features
sync_routes and dbx_team_policies only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Disabled
Team admin has opted out of File Provider Migration for team members.
Enabled
Team admin has not opted out of File Provider Migration for team members.
Default
Team admin has default value based on team tier.
Immediate
Team admin has chosen to do File Provider Migration immediately for the team.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.