#[non_exhaustive]pub enum TopLevelContentPolicy {
AdminOnly,
Everyone,
Other,
}Available on crate features
dbx_team_policies and sync_routes only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AdminOnly
Only admins can edit team folders at the top level of the team space.
Everyone
Everyone on the team can edit team folders at the top level of the team space.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.