ThumbnailV2Arg

Struct ThumbnailV2Arg 

#[non_exhaustive]
pub struct ThumbnailV2Arg { pub resource: PathOrLink, pub format: ThumbnailFormat, pub size: ThumbnailSize, pub mode: ThumbnailMode, pub quality: ThumbnailQuality, pub exclude_media_info: Option<bool>, }
Available on crate feature dbx_files only.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
resource: PathOrLink

Information specifying which file to preview. This could be a path to a file, a shared link pointing to a file, or a shared link pointing to a folder, with a relative path.

format: ThumbnailFormat

The format for the thumbnail image, jpeg (default), png, or webp. For images that are photos, jpeg should be preferred, while png is better for screenshots and digital arts, and web for compression.

size: ThumbnailSize

The size for the thumbnail image.

mode: ThumbnailMode

How to resize and crop the image to achieve the desired size.

quality: ThumbnailQuality

Quality of the thumbnail image.

exclude_media_info: Option<bool>

Normally, FileMetadata::media_info is set for photo and video. When this flag is true, FileMetadata::media_info is not populated. This improves latency for use cases where media_info is not needed.

Implementations

Source

impl ThumbnailV2Arg

pub fn new(resource: PathOrLink) -> Self

pub fn with_format(self, value: ThumbnailFormat) -> Self

pub fn with_size(self, value: ThumbnailSize) -> Self

pub fn with_mode(self, value: ThumbnailMode) -> Self

pub fn with_quality(self, value: ThumbnailQuality) -> Self

pub fn with_exclude_media_info(self, value: bool) -> Self