#[non_exhaustive]pub struct UploadSessionAppendBatchArg {
pub entries: Vec<UploadSessionAppendBatchArgEntry>,
pub content_hash: Option<Sha256HexHash>,
}Available on crate feature
dbx_files only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entries: Vec<UploadSessionAppendBatchArgEntry>Append information for each file in the batch.
content_hash: Option<Sha256HexHash>A hash of the entire request body which is all the concatenated pieces of file content that were uploaded in this call. If provided and the uploaded content does not match this hash, an error will be returned. For more information see our Content hash page.
Implementations
Sourceimpl UploadSessionAppendBatchArg
impl UploadSessionAppendBatchArg
pub fn new(entries: Vec<UploadSessionAppendBatchArgEntry>) -> Self
pub fn with_content_hash(self, value: Sha256HexHash) -> Self