#[non_exhaustive]pub struct UploadSessionAppendBatchArgEntry {
pub cursor: UploadSessionCursor,
pub length: u64,
pub close: bool,
}Available on crate feature
dbx_files only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cursor: UploadSessionCursorContains the upload session ID and the offset.
length: u64Length in bytes of the data that should be appended for this session. Used to split the batched upload data for multiple upload sessions.
close: boolIf true, the current session will be closed, at which point you won’t be able to call
upload_session_append_batch() anymore with
the current session.
Implementations
Sourceimpl UploadSessionAppendBatchArgEntry
impl UploadSessionAppendBatchArgEntry
pub fn new(cursor: UploadSessionCursor, length: u64) -> Self
pub fn with_close(self, value: bool) -> Self