#[non_exhaustive]pub struct PaperDocGetMetadataResult {
pub doc_id: PaperDocId,
pub owner: String,
pub title: String,
pub created_date: DropboxTimestamp,
pub status: PaperDocStatus,
pub revision: i64,
pub last_updated_date: DropboxTimestamp,
pub last_editor: String,
}Available on crate feature
dbx_paper only.Expand description
Metadata returned by docs/get_metadata.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.doc_id: PaperDocIdThe Paper doc ID.
owner: StringThe Paper doc owner’s email address.
title: StringThe Paper doc title.
created_date: DropboxTimestampThe Paper doc creation date.
status: PaperDocStatusThe Paper doc status.
revision: i64The Paper doc revision. Simply an ever increasing number.
last_updated_date: DropboxTimestampThe date when the Paper doc was last edited.
last_editor: StringThe email address of the last editor of the Paper doc.
Implementations
Sourceimpl PaperDocGetMetadataResult
impl PaperDocGetMetadataResult
pub fn new( doc_id: PaperDocId, owner: String, title: String, created_date: DropboxTimestamp, status: PaperDocStatus, revision: i64, last_updated_date: DropboxTimestamp, last_editor: String, ) -> Self