#[non_exhaustive]pub struct FolderLinkMetadata {
pub url: String,
pub name: String,
pub link_permissions: LinkPermissions,
pub id: Option<Id>,
pub expires: Option<DropboxTimestamp>,
pub path_lower: Option<String>,
pub team_member_info: Option<TeamMemberInfo>,
pub content_owner_team_info: Option<TeamInfo>,
}dbx_sharing only.Expand description
The metadata of a folder shared link.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: StringURL of the shared link.
name: StringThe linked file name (including extension). This never contains a slash.
link_permissions: LinkPermissionsThe link’s access permissions.
id: Option<Id>A unique identifier for the linked file.
expires: Option<DropboxTimestamp>Expiration time, if set. By default the link won’t expire.
path_lower: Option<String>The lowercased full path in the user’s Dropbox. This always starts with a slash. This field will only be present only if the linked file is in the authenticated user’s dropbox and the user is the owner of the link.
team_member_info: Option<TeamMemberInfo>The team membership information of the link’s owner. This field will only be present if the link’s owner is a team member.
content_owner_team_info: Option<TeamInfo>The team information of the content’s owner. This field will only be present if the content’s owner is a team member and the content’s owner team is different from the link’s owner team.
Implementations
Sourceimpl FolderLinkMetadata
impl FolderLinkMetadata
pub fn new(url: String, name: String, link_permissions: LinkPermissions) -> Self
pub fn with_id(self, value: Id) -> Self
pub fn with_expires(self, value: DropboxTimestamp) -> Self
pub fn with_path_lower(self, value: String) -> Self
pub fn with_team_member_info(self, value: TeamMemberInfo) -> Self
pub fn with_content_owner_team_info(self, value: TeamInfo) -> Self