#[non_exhaustive]pub struct GetTeamEventsArg {
pub limit: u32,
pub account_id: Option<AccountId>,
pub time: Option<TimeRange>,
pub category: Option<EventCategory>,
pub event_type: Option<EventTypeArg>,
}Available on crate feature
dbx_team_log only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.limit: u32The maximal number of results to return per call. Note that some calls may not return
limit number of events, and may even return no events, even with has_more set to true.
In this case, callers should fetch again using
get_events_continue().
account_id: Option<AccountId>Filter the events by account ID. Return only events with this account_id as either Actor, Context, or Participants.
time: Option<TimeRange>Filter by time range.
category: Option<EventCategory>Filter the returned events to a single category. Note that category shouldn’t be provided together with event_type.
event_type: Option<EventTypeArg>Filter the returned events to a single event type. Note that event_type shouldn’t be provided together with category.
Implementations
Sourceimpl GetTeamEventsArg
impl GetTeamEventsArg
pub fn with_limit(self, value: u32) -> Self
pub fn with_account_id(self, value: AccountId) -> Self
pub fn with_time(self, value: TimeRange) -> Self
pub fn with_category(self, value: EventCategory) -> Self
pub fn with_event_type(self, value: EventTypeArg) -> Self