#[non_exhaustive]pub enum DistinctMemberHomeValue {
Enabled(bool),
Other,
}Available on crate features
sync_routes and dbx_users only.Expand description
The value for UserFeature::DistinctMemberHome.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Enabled(bool)
When this value is True, the user have distinct home and root ns. When the value is False the user’s home ns and root ns are the same.
Other
Catch-all used for unrecognized values returned from the server. Encountering this value typically indicates that this SDK version is out of date.