pub fn list_folder_longpoll(
client: &impl NoauthClient,
arg: &ListFolderLongpollArg,
) -> Result<ListFolderLongpollResult, Error<ListFolderLongpollError>>Available on crate features
dbx_files and sync_routes only.Expand description
A longpoll endpoint to wait for changes on an account. In conjunction with
list_folder_continue(), this call gives you a
low-latency way to monitor an account for file changes. The connection will block until there
are changes available or a timeout occurs. This endpoint is useful mostly for client-side apps.