pub fn move_batch(
client: &impl UserAuthClient,
arg: &RelocationBatchArg,
) -> Result<RelocationBatchLaunch, Error<NoError>>👎Deprecated
Available on crate features
dbx_files and sync_routes only.Expand description
Move multiple files or folders to different locations at once in the user’s Dropbox. This route
will return job ID immediately and do the async moving job in background. Please use
move_batch_check() to check the job status.