upload_session_append_batch

Function upload_session_append_batch 

pub fn upload_session_append_batch(
    client: &impl UserAuthClient,
    arg: &UploadSessionAppendBatchArg,
    body: &[u8],
) -> Result<UploadSessionAppendBatchResult, Error<UploadSessionAppendBatchError>>
Available on crate features dbx_files and sync_routes only.
Append more data to multiple upload sessions. Each piece of file content to append to each upload session should be concatenated in the request body, in the order delineated by UploadSessionAppendBatchArg::entries and their individual lengths indicated by UploadSessionAppendBatchArgEntry::length. A single request should not upload more than 150 MiB. The maximum size of a file one can upload to an upload session is 2^41 - 2^22 (2,199,019,061,248) bytes. Calls to this endpoint will count as data transport calls for any Dropbox Business teams with a limit on the number of data transport calls allowed per month. For more information, see the Data transport limit page https://www.dropbox.com/developers/reference/data-transport-limit.