pub fn create_shared_link(
client: &impl UserAuthClient,
arg: &CreateSharedLinkArg,
) -> Result<PathLinkMetadata, Error<CreateSharedLinkError>>👎Deprecated
Available on crate features
dbx_sharing and sync_routes only.Expand description
Create a shared link. If a shared link already exists for the given path, that link is returned. Previously, it was technically possible to break a shared link by moving or renaming the corresponding file or folder. In the future, this will no longer be the case, so your app shouldn’t rely on this behavior. Instead, if your app needs to revoke a shared link, use revoke_shared_link. DEPRECATED: Use create_shared_link_with_settings instead.